@@ -358,7 +358,7 @@ class GameConqueror():
         response = dialog.run()
         if response == Gtk.ResponseType.OK:
             try:
-                with open(dialog.get_filename(), 'rb') as f:
+                with open(dialog.get_filename(), 'r') as f:
                     obj = json.load(f)
                     for row in obj['cheat_list']:
                         self.add_to_cheat_list(row[3],row[5],row[4],row[2])
@@ -378,7 +378,7 @@ class GameConqueror():
         response = dialog.run()
         if response == Gtk.ResponseType.OK:
             try:
-                with open(dialog.get_filename(), 'wb') as f:
+                with open(dialog.get_filename(), 'w') as f:
                     obj = {'cheat_list' : [list(i) for i in self.cheatlist_liststore]}
                     json.dump(obj, f);
             except:
@@ -915,7 +915,7 @@ class GameConqueror():
                 line = line[line.find(']')+1:]
                 (a, o, rt, v, t) = list(map(str.strip, line.split(',')[:5]))
                 a = '%x'%(int(a,16),)
-                o = '%x'%(int(o[5:],16),)
+                o = '%x'%(int(o.split('+')[1],16),)
                 t = t[1:-1]
                 if t == 'unknown':
                     continue
